package com.muyu.common.system.remote;

import com.muyu.common.core.constant.SecurityConstants;
import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.common.system.domain.Firm;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.domain.SysUserMessage;
import com.muyu.common.system.remote.factory.RemoteUserFallbackFactory;
import com.muyu.common.system.domain.LoginUser;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户服务
 *
 * @author muyu
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService {
    /**
     * 通过用户名查询用户信息
     *
     * @param username 用户名
     * @param source   请求来源
     *
     * @return 结果
     */
    @GetMapping("/user/info/{username}")
    public Result<LoginUser> getUserInfo (@PathVariable("username") String username, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @param source  请求来源
     *
     * @return 结果
     */
    @PostMapping("/user/register")
    public Result<Boolean> registerUserInfo (@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    @GetMapping("/user/companyList")
    public Result<List<SysUser>> companyList ();

    @GetMapping("/user/selectByfirmName/{firmName}")
    public Result<String> selectByfirmName(@PathVariable("firmName") String firmName);

    /**
     * 查询这个数据源中的登录账号和密码
     * @param sysUserMessage
     * @return
     */
    @PostMapping("/user/selectuser")
    public  Result<LoginUser> selectuser(@RequestBody SysUserMessage sysUserMessage );

    /**
     * 根据企业码查询对应数据源
     * @param firmName
     * @return
     */
    @RequestMapping("/firm/findByFirmName/{firmName}")
    public Result<Firm> findByFirmName(@PathVariable("firmName") String firmName);


    @RequestMapping("/firm/selectAll")
    public Result<List<Firm>> selectAll();
}
